@@ -1,4 +1,4 @@
-from abstract_webgui import *
+from abstract_gui import *
 import os
 from openpyxl import load_workbook
 import pandas as pd
